import { AbstractSession } from "@brightside/imperative";
import { IZosFilesResponse } from "../../doc/IZosFilesResponse";
import { ICopyDataSet } from ".";
/**
 * This class holds helper functions that are used to copy the contents of datasets through the
 * z/OSMF APIs.
 */
export declare class Copy {
    /**
     * Copy the contents of a dataset
     *
     * @param {AbstractSession}   session        - z/OSMF connection info
     * @param {ICopyDataSet}      fromDataSet    - The data set to copy from
     * @param {ICopyDataSet}      toDataSet      - The data set to copy to
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the status of the copying
     *
     * @throws {ImperativeError} Data set name must be specified as a non-empty string
     * @throws {Error} When the {@link ZosmfRestClient} throws an error
     *
     * @see https://www.ibm.com/support/knowledgecenter/en/SSLTBW_2.1.0/com.ibm.zos.v2r1.izua700/IZUHPINFO_API_PutDataSetMemberUtilities.htm
     */
    static dataSet(session: AbstractSession, { dataSetName: fromDataSetName, memberName: fromMemberName }: ICopyDataSet, { dataSetName: toDataSetName, memberName: toMemberName }: ICopyDataSet): Promise<IZosFilesResponse>;
}
